import{e as n}from"./index-DWBAd6A9.js";import{d as o,G as r,ae as i,u as a,am as l,e as t}from"./lucide-B8zdcbdX.js";const d=o({__name:"Spinner",props:{class:{type:[Boolean,null,String,Object,Array],default:void 0},size:{default:void 0}},setup(s){const e=s;return(c,p)=>(t(),r(a(l),{role:"status","aria-label":"Loading",size:e.size,class:i(a(n)("size-4 animate-spin",e.class))},null,8,["size","class"]))}});export{d as _};
